@@ -9,6 +9,7 @@
 #include "cmor_locale.h"
 #include <json-c/json.h>
 #include <json-c/json_tokener.h>
+#include <json-c/arraylist.h>
 #include <sys/stat.h>
 
 /************************************************************************/
@@ -171,6 +172,9 @@ int cmor_set_variable_entry(cmor_table_t * table,
     char msg[CMOR_MAX_STRING];
     int nVarId;
     char *szTableId;
+    array_list *jsonArray;
+    json_object *jsonItem;
+    size_t k, arrayLen;
     cmor_var_def_t *variable;
     cmor_table_t *cmor_table;
     cmor_table = &cmor_tables[cmor_ntables];
@@ -208,7 +212,26 @@ int cmor_set_variable_entry(cmor_table_t * table,
         if (attr[0] == '#')
             continue;
 
-        strcpy(szValue, json_object_get_string(value));
+/* -------------------------------------------------------------------- */
+/*  Attribute values that are arrays will have their array elements     */
+/*  combined into space-separated lists.                                */
+/* -------------------------------------------------------------------- */
+        if(json_object_is_type(value, json_type_array)) {
+            jsonArray = json_object_get_array(value);
+            arrayLen = array_list_length(jsonArray);
+            for (k = 0; k < arrayLen; k++) {
+                jsonItem = (json_object *) array_list_get_idx(jsonArray, k);
+                if (k == 0) {
+                    strcpy(szValue, json_object_get_string(jsonItem));
+                } else {
+                    strcat(szValue, " ");
+                    strcat(szValue, json_object_get_string(jsonItem));
+                }
+            }
+        } else {
+            strcpy(szValue, json_object_get_string(value));
+        }
+
         cmor_set_var_def_att(variable, attr, szValue);
     }
     cmor_pop_traceback();
@@ -772,6 +795,18 @@ int cmor_load_table_internal(char szTable[CMOR_MAX_STRING], int *table_id)
         return (TABLE_ERROR);
     }
 
+/* -------------------------------------------------------------------- */
+/*     check for null values in JSON                                    */
+/* -------------------------------------------------------------------- */
+    if(cmor_validate_json(json_obj) != 0) {
+        snprintf(msg, CMOR_MAX_STRING,
+                 "There are invalid null values in table: %s", 
+                 szTable);
+        cmor_handle_error(msg, CMOR_CRITICAL);
+        cmor_pop_traceback();
+        return (TABLE_ERROR);
+    }
+
     json_object_object_foreach(json_obj, key, value) {
 
         if (key[0] == '#') {
@@ -985,3 +1020,37 @@ int cmor_load_table_internal(char szTable[CMOR_MAX_STRING], int *table_id)
     json_object_put(json_obj);
     return (TABLE_SUCCESS);
 }
+
+
+/************************************************************************/
+/*                      cmor_validate_json()                            */
+/************************************************************************/
+int cmor_validate_json(json_object *json)
+{
+    json_object *value;
+    array_list *array;
+    size_t length, k;
+
+    if (json_object_is_type(json, json_type_null)) {
+        // null is invalid
+        return 1;
+    } else if (json_object_is_type(json, json_type_object)) {
+        // validate values within JSON object
+        json_object_object_foreach(json, key, value) {
+            if (cmor_validate_json(value) == 1)
+                return 1;
+        }
+    } else if (json_object_is_type(json, json_type_array)) {
+        // validate values within JSON list
+        array = json_object_get_array(json);
+        length = array_list_length(array);
+        for (k = 0; k < length; k++) {
+            value = (json_object *) array_list_get_idx(array, k);
+            if (cmor_validate_json(value) == 1)
+                return 1;
+        }
+    }
+
+    return 0;
+
+}
\ No newline at end of file
