@@ -3,7 +3,7 @@ import numpy
 
 error_flag = cmor.setup(inpath='Tables', netcdf_file_action=cmor.CMOR_REPLACE)
 
-error_flag = cmor.dataset_json("Test/common_user_input.json")
+error_flag = cmor.dataset_json("Test/CMOR_input_example.json")
 
 
 cmor.load_table("CMIP6_Omon.json")
